==> cornice-2.0.2.zip: cornice-2.0.2/cornice/validators/__init__.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this file,
# You can obtain one at http://mozilla.org/MPL/2.0/.
from webob.multidict import MultiDict
from cornice.validators._colander import (
    validator as colander_validator,
    body_validator as colander_body_validator)


__all__ = ['colander_validator',
           'colander_body_validator',
           'extract_cstruct',
           'DEFAULT_VALIDATORS',
           'DEFAULT_FILTERS']


DEFAULT_VALIDATORS = []
DEFAULT_FILTERS = []


def extract_cstruct(request):
    """
    Extract attributes from the specified `request` such as body, url, path,
    method, querystring, headers, cookies, and returns them in a single dict
    object.

    :param request: Current request
    :type request: :class:`~pyramid:pyramid.request.Request`

    :returns: A mapping containing most request attributes.
    :rtype: dict
    """
    if request.content_type == 'application/x-www-form-urlencoded':
        body = request.POST.mixed()

    elif request.content_type and request.content_type != 'application/json':
        body = request.body
    else:
        if request.body:
            try:
                body = request.json_body
            except ValueError as e:
                request.errors.add('body', '', 'Invalid JSON: %s' % e)
                return {}
            else:
                if not hasattr(body, 'items'):
                    request.errors.add('body', '', 'Should be a JSON object')
                    return {}
        else:
            body = {}

    cstruct = {'method': request.method,
               'url': request.url,
               'path': request.path,
               'body': body}

    for sub, attr in (('querystring', 'GET'),
                      ('header', 'headers'),
                      ('cookies', 'cookies')):
        data = getattr(request, attr)
        if isinstance(data, MultiDict):
            data = data.mixed()
        else:
            data = dict(data)
        cstruct[sub] = data

    return cstruct

==> cornice-2.1.0.zip: cornice-2.1.0/cornice/validators/__init__.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this file,
# You can obtain one at http://mozilla.org/MPL/2.0/.
from webob.multidict import MultiDict
from cornice.validators._colander import (
    validator as colander_validator,
    body_validator as colander_body_validator)


__all__ = ['colander_validator',
           'colander_body_validator',
           'extract_cstruct',
           'DEFAULT_VALIDATORS',
           'DEFAULT_FILTERS']


DEFAULT_VALIDATORS = []
DEFAULT_FILTERS = []


def extract_cstruct(request):
    """
    Extract attributes from the specified `request` such as body, url, path,
    method, querystring, headers, cookies, and returns them in a single dict
    object.

    :param request: Current request
    :type request: :class:`~pyramid:pyramid.request.Request`

    :returns: A mapping containing most request attributes.
    :rtype: dict
    """
    if request.content_type == 'application/x-www-form-urlencoded':
        body = request.POST.mixed()

    elif request.content_type and request.content_type != 'application/json':
        body = request.body
    else:
        if request.body:
            try:
                body = request.json_body
            except ValueError as e:
                request.errors.add('body', '', 'Invalid JSON: %s' % e)
                return {}
            else:
                if not hasattr(body, 'items'):
                    request.errors.add('body', '', 'Should be a JSON object')
                    return {}
        else:
            body = {}

    cstruct = {'method': request.method,
               'url': request.url,
               'path': request.matchdict,
               'body': body}

    for sub, attr in (('querystring', 'GET'),
                      ('header', 'headers'),
                      ('cookies', 'cookies')):
        data = getattr(request, attr)
        if isinstance(data, MultiDict):
            data = data.mixed()
        else:
            data = dict(data)
        cstruct[sub] = data

    return cstruct
